#!/usr/bin/env bash
# Path to current script
SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )"
TOOLS=$SCRIPT_DIR/$(cat toolspath); cd $TOOLS

# Add current working directory to executable namespace
export PATH=$PATH:$TOOLS
# Setup root directory for resolution of imports:
# the path of all local python libraries are relative to this
export PYTHONPATH=$TOOLS

# Each command outputs the run directory, which is then used
# by the next command to add parameters and generate information
# used by the simulator. For a list of available options for each
# command, run 'export PYTHONPATH=.; <command> --help'.
setup/meta.py \
  --script $SCRIPT_DIR/`basename "$0"` \
  --results-directory $SCRIPT_DIR/tmp \
  --seed 1 |
setup/dataset.py \
  --name cifar10 \
  --train-examples-per-class 5000 5000 5000 5000 5000 5000 5000 5000 5000 5000 \
  --validation-examples-per-class 0 0 0 0 0 0 0 0 0 0 |
setup/nodes.py \
  --name iid-eq-classes \
  --nb-nodes 1 \
  --nodes-per-class 1 1 1 1 1 1 1 1 1 1 \
  --local-classes 10 |
setup/topology/fully-connected.py |
setup/model/gn_lenet.py |
simulate/algorithm/d_sgd.py \
  --batch-size 2000 \
  --learning-momentum 0.9 \
  --learning-rate 0.002 |
simulate/logger.py \
  --accuracy-logging-interval 10\
  --nb-processes 1 |
simulate/run.py \
  --nb-epochs 100
